@@ -4,7 +4,7 @@ AHA - Simple access to the AHA interface for AVM based home automation
 
 =head1 SYNOPSIS
 
-    my $aha = new AHA({host: "fritz.box", password: "s!cr!t"});
+    my $aha = AHA->new( { host => "fritz.box", password => "s!cr!t" } );
 
     # Get all switches as array ref of AHA::Switch objects
     my $switches = $aha->list();
@@ -16,6 +16,7 @@ AHA - Simple access to the AHA interface for AVM based home automation
        say "Present: ",$switch->is_present();
        say "Energy:  ",$switch->energy();
        say "Power:   ",$switch->power();
+       say "Temp.°C: ",$switch->temperature() / 10;
 
        # If switch is on, switch if off and vice versa
        $switch->is_on() ? $switch->off() : $switch->on();
@@ -82,7 +83,7 @@ use Digest::MD5;
 use Data::Dumper;
 use vars qw($VERSION);
 
-$VERSION = "0.55";
+$VERSION = "0.6";
 
 # Set to one if some debugging should be printed
 my $DEBUG = 0;
@@ -233,6 +234,18 @@ sub power {
     return &_inval_check($self->_execute_cmd("getswitchpower",$self->_ain(shift)));
 }
 
+=item $temperature = $aha->temperature($ain)
+
+Get the current temperature of the switch C<$ain> in 0,1 °C.
+If the switch is not connected, C<undef> is returned.
+
+=cut
+
+sub temperature {
+    my $self = shift;
+    return &_inval_check($self->_execute_cmd("gettemperature",$self->_ain(shift)));
+}
+
 =item $name = $aha->name($ain)
 
 Get the symbolic name for the AIN given. In this case C<$ain> must be an real
@@ -246,7 +259,7 @@ sub name {
     return $self->_execute_cmd("getswitchname",$ain);
 }
 
-=item $ain = $aha->ain($name)
+=item $ain = $aha->ain_by_name($name)
 
 This is the inverse method to C<name()>. It takes a symbolic name C<$name> as
 argument and returns the AIN. If no such name is registered, an error is
